export default {
    "index": 19,
    "lineNumber": 2,
    "column": 1,
    "message": "Deleting local variable in strict mode"
};